@@ -4,7 +4,6 @@ import json
 from ruamel import yaml
 
 from .models import Intent, Entity
-from .api import ApiAi
 
 
 
@@ -15,7 +14,7 @@ class SchemaHandler(object):
 
         self.assist = assist
         self.intents = []
-        self.api = ApiAi()
+        self.api = assist.api
         self.object_type = object_type
 
     # File set up
@@ -121,7 +120,10 @@ class IntentGenerator(SchemaHandler):
     def build_intent(self, intent_name):
         """Builds an Intent object of the given name"""
         # TODO: contexts
-        new_intent = Intent(intent_name)
+        is_fallback = self.assist._intent_fallbacks[intent_name]
+        contexts = self.assist._required_contexts[intent_name]
+        events = self.assist._intent_events[intent_name]
+        new_intent = Intent(intent_name, fallback_intent=is_fallback, contexts=contexts, events=events)
         self.build_action(new_intent)
         self.build_user_says(new_intent)  # TODO
         return new_intent
@@ -170,6 +172,15 @@ class IntentGenerator(SchemaHandler):
             params.append(param_info)
         return params
 
+    def get_synonyms(self, annotation, entity):
+        raw_temp = self.entity_yaml()
+        for temp_dict in [d for d in raw_temp if d == entity]:
+            for entry in raw_temp.get(temp_dict):
+                if isinstance(entry, dict):
+                    for a, s in entry.items():
+                        if a == annotation:
+                            for synonym in s:
+                                yield(synonym)
 
     def build_user_says(self, intent):
         raw = self.user_says_yaml()
@@ -178,15 +189,20 @@ class IntentGenerator(SchemaHandler):
         if intent_data:
             phrases = intent_data.get('UserSays', [])
             annotations = intent_data.get('Annotations', [])
+            events = intent_data.get('Events', [])
             mapping = {}
             for a in [a for a in annotations if a]:
-                mapping.update(a)
+                for annotation, entity in a.items():
+                    mapping.update({str(annotation):str(entity)})
+                    for synonym in self.get_synonyms(annotation, entity):
+                        mapping.update({str(synonym):str(entity)})
 
             for phrase in [p for p in phrases if p]:
                 if phrase != '':
                     intent.add_example(phrase, templ_entity_map=mapping)
 
-
+            for event in [e for e in events if e]:
+                intent.add_event(event)
 
 
     def push_intent(self, intent):
@@ -351,6 +367,7 @@ class TemplateCreator(SchemaHandler):
             d = yaml.compat.ordereddict()
             d['UserSays'] = [None, None]
             d['Annotations'] = [None, None]
+            d['Events'] = [None]
 
             # d['Annotations'] = self.parse_annotations_from_action_mappings(intent)
 
@@ -365,7 +382,9 @@ class TemplateCreator(SchemaHandler):
             f.write('#    - red is my favorite color\n\n')
             f.write('#  Annotations:\n')
             f.write('#    - blue: sys.color     # maps param value -> entity\n')
-            f.write('#    - red: sys.color\n\n\n\n')
+            f.write('#    - red: sys.color\n\n')
+            f.write('#  Events:\n')
+            f.write('#    - event1              # adds a triggerable event named \'event1\' to the intent\n\n\n\n')
             # f.write(header)
             yaml.dump(skeleton, f, default_flow_style=False, Dumper=yaml.RoundTripDumper)
 
